pub enum OxeylyzerError {
InvalidBigramLength(usize),
InvalidTrigramLength(usize),
ChunkerInitError,
ChunkerChunkError,
NotAFile(PathBuf),
PathDoesNotExist(PathBuf),
MissingDataName,
CouldNotSerializeData(String),
InvalidCorpusPath(PathBuf),
AnyhowError(Error),
}Expand description
Errors that can occur within the oxeylyzer-core crate.
Variants
InvalidBigramLength(usize)
Encountered a bigram that does not have a length of 2.
InvalidTrigramLength(usize)
Encountered a trigram that does not have a length of 3.
ChunkerInitError
Failed to initialize the file chunker for corpus processing.
ChunkerChunkError
Failed to split the corpus into valid chunks.
NotAFile(PathBuf)
The provided path is not a file or directory.
PathDoesNotExist(PathBuf)
The specified path does not exist on the file system.
MissingDataName
No name was provided for the corpus data.
CouldNotSerializeData(String)
Could not serialize the processed data to JSON.
InvalidCorpusPath(PathBuf)
The corpus output path is invalid (usually missing .json extension).
AnyhowError(Error)
Wrapper for general anyhow errors.